package server

import (
	"crypto/tls"
	"gitea.com/go-chi/session"
	"github.com/go-chi/chi/v5"
	"github.com/go-chi/chi/v5/middleware"
	"gitlab.schukai.com/oss/utilities/conan/configuration"
	"gitlab.schukai.com/oss/utilities/conan/constants"
	"gitlab.schukai.com/oss/utilities/conan/header"
	"gitlab.schukai.com/oss/utilities/conan/logging"
	"gitlab.schukai.com/oss/utilities/conan/websocket"
	"net/http"
)

func getRouter() *chi.Mux {

	/** x509: certificate signed by unknown authority */
	http.DefaultTransport.(*http.Transport).TLSClientConfig = &tls.Config{InsecureSkipVerify: true}

	router := chi.NewRouter()

	router.Use(middleware.RealIP)
	router.Use(middleware.Heartbeat("ping"))

	router.Use(header.RequestIDMiddleware)

	router.Use(middleware.Compress(5))
	router.Use(logging.LoggerMiddleware)
	router.Use(reloadMiddleware)
	router.Use(NoCache)

	router.Use(session.Sessioner())

	router.Handle(constants.WebsocketPath, websocket.GetWebsocketHandler())

	//fs := NoListFileSystem{http.Dir(configuration.GetServerWebPath() + "/")}
	//	router.Handle("*.html", injectHandler(http.FileServer(http.Dir(configuration.GetServerWebPath()+"/"))))
	router.Handle("/*", injectHandler(http.FileServer(http.Dir(configuration.GetServerWebPath()+"/"))))

	return router

}
