package server

import (
	"encoding/json"
	"fmt"
	"github.com/go-chi/chi/v5"
	"gitlab.schukai.com/oss/utilities/conan/constants"
	error2 "gitlab.schukai.com/oss/utilities/conan/error"
	"gitlab.schukai.com/oss/utilities/conan/header"
	"gitlab.schukai.com/oss/utilities/conan/negotiator"
	"go.uber.org/zap"
	"net/http"
)

type WebManifest struct {
	Name      string `json:"name"`
	ShortName string `json:"short_name"`
	Scope     string `json:"scope"`

	StartUrl            string                           `json:"start_url"`
	Display             string                           `json:"display"`
	BackgroundColor     string                           `json:"background_color"`
	Description         string                           `json:"description"`
	Icons               []WebManifestIcons               `json:"icons"`
	RelatedApplications []WebManifestRelatedApplications `json:"related_applications"`
}

type WebManifestRelatedApplications struct {
	Platform string `json:"platform"`
	Url      string `json:"url,omitempty"`
}

type WebManifestIcons struct {
	Src   string `json:"src"`
	Sizes string `json:"sizes"`
	Type  string `json:"type"`
}

func GetWebmanifestHandler() http.Handler {

	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {

		neg := negotiator.New(r.Header)

		a := neg.Type("application/json")
		fmt.Println(a)

		if neg.Type("application/json") == "" {
			error2.StandardErrorResponse(w, r,
				error2.ErrorResponse{
					Status: http.StatusNotAcceptable,
					Hint:   "the webmanifest is only available for the app as a json file",
				})
			return
		}

		//r, _ = DoCheck(w, r)
		//if r == nil {
		//	return
		//}

		appID := chi.RouteContext(r.Context()).URLParam("appID")

		manifest := WebManifest{
			Name:            appID,
			ShortName:       appID,
			Scope:           "/app/" + appID,
			StartUrl:        "/app/" + appID,
			Display:         "standalone", // fullscreen,minimal-ui,standalone,browser
			BackgroundColor: "#ffffff",
			Description:     appID,
			Icons: []WebManifestIcons{
				{
					Src:   "/app/" + appID + "/" + constants.AssetsPath + "/android-chrome-192x192.png",
					Sizes: "192x192",
					Type:  "image/png",
				},
				{
					Src:   "/app/" + appID + "/" + constants.AssetsPath + "/android-chrome-512x512.png",
					Sizes: "512x512",
					Type:  "image/png",
				},
			},
			RelatedApplications: []WebManifestRelatedApplications{
				{
					Platform: "android",
					Url:      "https://play.google.com/store/apps/details?id=com.agenor.app." + appID,
				},
				{
					Platform: "ios",
					Url:      "https://itunes.apple.com/us/app/agenor-app/" + appID + "?ls=1&mt=8",
				},
			},
		}

		b, err := json.Marshal(manifest)
		if err != nil {
			zap.S().Error("json.Marshal fail: %s", err)
		}

		w.Header().Set(header.ContentType, "application/manifest+json")
		w.WriteHeader(http.StatusOK)

		_, _ = w.Write(b)

	})
}
